rnalysis.enrichment.FeatureSet
========================================

.. currentmodule:: rnalysis.enrichment

.. autoclass:: FeatureSet


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::
    :toctree:

      ~FeatureSet.__init__
      ~FeatureSet.biotypes
      ~FeatureSet.difference
      ~FeatureSet.enrich_randomization
      ~FeatureSet.enrich_randomization_parallel
      ~FeatureSet.go_enrichment
      ~FeatureSet.intersection
      ~FeatureSet.save_txt
      ~FeatureSet.symmetric_difference
      ~FeatureSet.union





